import { normalise } from "./basepath";
import { dropLocaleFromPath } from "./locale";
import { matchDynamic } from "../match";
import { getRewritePath, isExternalRewrite } from "./rewrite";
export const handleApiReq = (req, uri, manifest, routesManifest, isRewrite) => {
    const { apis } = manifest;
    const normalisedUri = normalise(uri, routesManifest);
    const nonDynamic = apis.nonDynamic[normalisedUri];
    if (nonDynamic) {
        return {
            isApi: true,
            page: nonDynamic
        };
    }
    const rewrite = !isRewrite && getRewritePath(req, uri, routesManifest);
    if (rewrite) {
        // Rewrites include locales even for api routes
        const apiRewrite = dropLocaleFromPath(rewrite, routesManifest);
        const [path, querystring] = apiRewrite.split("?");
        if (isExternalRewrite(path)) {
            return {
                isExternal: true,
                path,
                querystring
            };
        }
        const route = handleApiReq(req, path, manifest, routesManifest, true);
        if (route) {
            return {
                ...route,
                querystring
            };
        }
        return route;
    }
    const dynamic = matchDynamic(normalisedUri, apis.dynamic);
    if (dynamic) {
        return {
            isApi: true,
            page: dynamic
        };
    }
};
