"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderPageToHtml = void 0;
const utils_1 = require("next/dist/server/utils");
/**
 * Render to HTML helper. Starting in Next.js 11.1 a change was introduced so renderReqToHTML no longer returns a string.
 * See: https://github.com/vercel/next.js/pull/27319
 * This is a helper to properly render it in backwards compatible way.
 * @param page
 * @param req
 * @param res
 * @param renderMode
 */
const renderPageToHtml = async (page, req, res, renderMode) => {
    const { renderOpts, html: htmlResult } = await page.renderReqToHTML(req, res, renderMode);
    let html;
    try {
        if (typeof htmlResult === "string") {
            html = htmlResult; // Next.js < 11.1
        }
        else {
            html = htmlResult ? await (0, utils_1.resultsToString)([htmlResult]) : ""; // Next >= 11.1.1
        }
    }
    catch (e) {
        // Fallback to using renderReqToHtml without renderMode specified,
        // which will render html based on the page's renderReqToHtml,
        // which should always work (but adds another *warm* render cost)
        console.log("Falling back to using page's rendering function for html");
        html = (await page.renderReqToHTML(req, res));
    }
    return { html, renderOpts };
};
exports.renderPageToHtml = renderPageToHtml;
